@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,15 +37,17 @@
 #ifndef LIBTORRENT_TORRENT_EVENT_H
 #define LIBTORRENT_TORRENT_EVENT_H
 
+#include <torrent/common.h>
+
 namespace torrent {
 
-class Event {
+class LIBTORRENT_EXPORT Event {
 public:
   virtual ~Event() {}
 
   // These are not virtual as the fd is heavily used in select based
   // polling, thus fast access is critical to performance.
-  int                 file_descriptor() { return m_fileDesc; }
+  int                 file_descriptor() const { return m_fileDesc; }
 
   virtual void        event_read() = 0;
   virtual void        event_write() = 0;
