@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,15 +37,14 @@
 #ifndef LIBTORRENT_TRACKER_H
 #define LIBTORRENT_TRACKER_H
 
+#include <string>
 #include <torrent/common.h>
 
 namespace torrent {
 
-class TrackerBase;
-
 // Consider changing into a Download + tracker id.
 
-class Tracker {
+class LIBTORRENT_EXPORT Tracker {
 public:
   typedef std::pair<int, TrackerBase*> value_type;
 
@@ -71,6 +70,14 @@ public:
   const std::string&  tracker_id() const;
   Type                tracker_type() const;
 
+  uint32_t            normal_interval() const;
+  uint32_t            min_interval() const;
+
+  uint64_t            scrape_time_last() const;
+  uint32_t            scrape_complete() const;
+  uint32_t            scrape_incomplete() const;
+  uint32_t            scrape_downloaded() const;
+
 private:
   value_type          m_tracker;
 };
